from setuptools import setup

setup(name='funny123',
      version='0.3',
      description='The funniest joke in the world',
      author='Flying Circus',
      author_email='flyingcircus@example.com',
      license='MIT',
      packages=['funny123'],
      zip_safe=False)